#include "common.hh"
#include "method1.hh"
#include "parseargs.hh"

int main(int ac, char **av) {
  auto const [input_file, output_file, video_output, iterations, method] =
      parse_args(ac, av);
  spdlog::info("Input file:\t{}", input_file.native());
  spdlog::info("Output file:\t{}", output_file.native());
  spdlog::info("Video output:\t{}", video_output);
  spdlog::info("Iterations:\t{}", iterations);
  auto [input_image, process_image] = init_image(input_file.native());
  std::random_device rd;
  std::mt19937 gen(rd());

  switch (method) {
  case 1: {
    method1(input_image, process_image, iterations, gen);
    break;
  }
  case 2: {
    method2(input_image, process_image, iterations, gen);
    break;
  }
  default:
    spdlog::error("Requested method {} is not implemented.");
    std::exit(-1);
  }

  cv::imwrite(output_file.native(), process_image);

  // Launch image generation

  return 0;
}
